@@ -1,6 +1,7 @@
-(def ks-version "1.0.0")
+(def ks-version "1.3.0")
+(def logback-version "1.1.3")
 
-(defproject puppetlabs/trapperkeeper "1.1.1"
+(defproject puppetlabs/trapperkeeper "1.4.0"
   :description "A framework for configuring, composing, and running Clojure services."
   ;; Abort when version ranges or version conflicts are detected in
   ;; dependencies. Also supports :warn to simply emit warnings.
@@ -11,14 +12,23 @@
                  [clj-time "0.5.1"]
                  [puppetlabs/kitchensink ~ks-version]
                  [prismatic/plumbing "0.4.2"]
-                 [prismatic/schema "0.4.0"]
+                 [prismatic/schema "1.0.4"]
                  [org.clojure/tools.nrepl "0.2.3"]
                  [org.clojure/tools.macro "0.1.2"]
-                 [ch.qos.logback/logback-classic "1.1.1"]
+                 [ch.qos.logback/logback-classic ~logback-version]
+                 ;; even though we don't strictly have a dependency on the following two
+                 ;; logback artifacts, specifying the dependency version here ensures
+                 ;; that downstream projects don't pick up different versions that would
+                 ;; conflict with our version of logback-classic
+                 [ch.qos.logback/logback-core ~logback-version]
+                 [ch.qos.logback/logback-access ~logback-version]
+                 [org.slf4j/log4j-over-slf4j "1.7.6"]
                  [org.codehaus.janino/janino "2.7.8"]
-                 [puppetlabs/typesafe-config "0.1.1"]
-                 [me.raynes/fs "1.4.5"]
-                 [clj-yaml "0.4.0"]]
+                 [puppetlabs/typesafe-config "0.1.5"]
+                 [me.raynes/fs "1.4.6"]
+                 [clj-yaml "0.4.0"]
+                 [beckon "0.1.1"]
+                 [org.clojure/core.async "0.2.374"]]
 
   :lein-release {:scm         :git
                  :deploy-via  :lein-deploy}
@@ -29,7 +39,8 @@
                                      :sign-releases false}]]
 
   ;; Convenience for manually testing application shutdown support - run `lein test-external-shutdown`
-  :aliases {"test-external-shutdown" ["trampoline" "run" "-m" "examples.shutdown-app.test-external-shutdown"]}
+  :aliases {"cljfmt" ["with-profile" "+cljfmt" "cljfmt"]
+            "test-external-shutdown" ["trampoline" "run" "-m" "examples.shutdown-app.test-external-shutdown"]}
 
   ;; By declaring a classifier here and a corresponding profile below we'll get an additional jar
   ;; during `lein jar` that has all the code in the test/ directory. Downstream projects can then
@@ -37,7 +48,11 @@
   ;; code that we have.
   :classifiers [["test" :testutils]]
 
-  :profiles {:dev {:source-paths ["examples/shutdown_app/src"
+  :profiles {:cljfmt {:plugins [[lein-cljfmt "0.5.0"]
+                                [lein-parent "0.2.1"]]
+                      :parent-project {:path "ext/pl-clojure-style/project.clj"
+                                       :inherit [:cljfmt]}}
+             :dev {:source-paths ["examples/shutdown_app/src"
                                   "examples/java_service/src/clj"]
                    :java-source-paths ["examples/java_service/src/java"]
                    :dependencies [[spyscope "0.1.4"]
